import { SigHashOptions, TxData, TxTemplate } from '@scrow/tapscript';
import { CoreClient } from './client.js';
import { AddressConfig, AddressInfo, MethodArgs, UTXO, WalletInfo } from '../types/index.js';
export declare class CoreWallet {
    readonly _client: CoreClient;
    readonly _name: string;
    readonly _txfee: number;
    _info?: WalletInfo;
    constructor(client: CoreClient, label?: string, txfee?: number);
    get client(): CoreClient;
    get info(): Promise<WalletInfo>;
    get name(): string;
    get balance(): Promise<number>;
    get network(): string;
    get newaddress(): Promise<string>;
    get utxos(): Promise<{
        sats: number;
        txid: string;
        vout: number;
        address: string;
        label: string;
        scriptPubKey: string;
        amount: number;
        confirmations: number;
        spendable: boolean;
        solvable: boolean;
        desc: string;
        parent_descs: string[];
        safe: boolean;
    }[]>;
    get xprvs(): Promise<import("../types/descriptors.js").DescriptorData[]>;
    get xpubs(): Promise<import("../types/descriptors.js").DescriptorData[]>;
    cmd<T = Record<string, string>>(method: string, args?: MethodArgs, params?: string[]): Promise<T>;
    get_info(refresh?: boolean): Promise<WalletInfo>;
    gen_address(config?: AddressConfig): Promise<string>;
    get_address(label: string): Promise<string>;
    parse_address(address: string): Promise<AddressInfo>;
    send_funds(address: string, amt: number): Promise<string>;
    ensure_funds(min_bal: number, blocks?: number): Promise<void>;
    ensure_txfee_config(): Promise<void>;
    generate_funds(blocks?: number, address?: string): Promise<void>;
    get_xprv(label: string): Promise<import("../types/descriptors.js").DescriptorData | undefined>;
    get_signer(desc: string): Promise<{
        pubkey: import("@cmdcode/buff").Buff;
        sign_tx: (txdata: TxData, config: SigHashOptions) => import("@cmdcode/buff").Buff;
    }>;
    create_vout(amount: number | bigint, address?: string): Promise<{
        value: bigint;
        scriptPubKey: string;
    }>;
    select_utxos(amount: number, sorter?: () => 1 | -1): Promise<UTXO[]>;
    fund_tx(templ: TxTemplate, config?: SigHashOptions, txfee?: number): Promise<TxData>;
}
//# sourceMappingURL=wallet.d.ts.map